@@ -51,6 +51,8 @@ class DomCompleteBackup(_BaseDomBackup):
         packager_opts=None,
         definition_filename=None,
     ):
+        super().__init__()
+
         #: domain name
         self.dom_name = dom_name
 
@@ -157,7 +159,7 @@ class DomCompleteBackup(_BaseDomBackup):
         """
         packager = self._get_packager()
         with packager:
-            return packager.restore(self.disks[disk], target)
+            return packager.restore(self.disks[disk], target, self._cancel_flag)
 
     def _get_packager(self):
         return self._get_read_packager(self.name)
