@@ -14,6 +14,7 @@ from virt_backup.compat_layers.pending_info import (
     convert as compat_convert_pending_info,
 )
 from virt_backup.domains import get_xml_block_of_disk
+from virt_backup.exceptions import CancelledError
 from virt_backup.tools import copy_file
 from . import _BaseDomBackup
 from .snapshot import DomExtSnapshot
@@ -59,6 +60,7 @@ class DomBackup(_BaseDomBackup):
         disks=None,
         ext_snapshot_helper=None,
         callbacks_registrer=None,
+        quiesce=False,
     ):
         """
         :param dev_disks: list of disks dev names to backup. Disks will be
@@ -69,6 +71,8 @@ class DomBackup(_BaseDomBackup):
                       `{"src": disk_path, "type": disk_format}`. Prefer
                       using dev disks when possible.
         """
+        super().__init__()
+
         #: domain to backup. Has to be a libvirt.virDomain object
         self.dom = dom
 
@@ -101,6 +105,11 @@ class DomBackup(_BaseDomBackup):
         #  timeout is None
         self.timeout = timeout
 
+        #: quiesce enable the Livirt Quiesce options when taking the external snapshot.
+        #  It allows to freeze the filesystem before the snapshot, but requires qemu
+        #  guest agent to run inside the VM.
+        self.quiesce = quiesce
+
         #: droppable helper to take and clean external snapshots. Can be
         #  construct with an ext_snapshot_helper to clean the snapshots of an
         #  aborted backup. Starting a backup will erase this helper.
@@ -154,12 +163,17 @@ class DomBackup(_BaseDomBackup):
                 continue
             self.disks[dev] = dom_all_disks[dev]
 
+    def cancel(self):
+        self._cancel_flag.set()
+
     def start(self):
         """
         Start the entire backup process for all disks in self.disks
         """
         assert not self.running
         assert self.dom and self.backup_dir
+        self._cancel_flag.clear()
+
         if not os.path.exists(self.backup_dir):
             os.mkdir(self.backup_dir)
 
@@ -169,9 +183,7 @@ class DomBackup(_BaseDomBackup):
 
         try:
             self._running = True
-            self._ext_snapshot_helper = DomExtSnapshot(
-                self.dom, self.disks, self._callbacks_registrer, self.conn, self.timeout
-            )
+            self._ext_snapshot_helper = self._get_ext_snapshot_helper()
 
             snapshot_date, definition = self._snapshot_and_save_date(definition)
 
@@ -184,6 +196,9 @@ class DomBackup(_BaseDomBackup):
             # TODO: handle backingStore cases
             with packager:
                 for disk, prop in self.disks.items():
+                    if self._cancel_flag.is_set():
+                        raise CancelledError()
+
                     self._backup_disk(disk, prop, packager, definition)
                     self._ext_snapshot_helper.clean_for_disk(disk)
 
@@ -197,6 +212,16 @@ class DomBackup(_BaseDomBackup):
             self._running = False
         logger.info("%s: Backup finished", self.dom.name())
 
+    def _get_ext_snapshot_helper(self):
+        return DomExtSnapshot(
+            self.dom,
+            self.disks,
+            self._callbacks_registrer,
+            self.conn,
+            self.timeout,
+            quiesce=self.quiesce,
+        )
+
     def _get_packager(self):
         assert self._name, "_name attribute needs to be defined to get a packager"
         return self._get_write_packager(self._name)
@@ -262,7 +287,7 @@ class DomBackup(_BaseDomBackup):
             definition["disks"] = {}
         definition["disks"][disk] = bak_img
 
-        packager.add(disk_properties["src"], bak_img)
+        packager.add(disk_properties["src"], bak_img, self._cancel_flag)
 
     def _disk_backup_name_format(self, snapdate, disk_name, *args, **kwargs):
         """
@@ -298,12 +323,21 @@ class DomBackup(_BaseDomBackup):
         disks names and other informations
         """
         backup_date = arrow.get(definition["date"]).to("local")
-        definition_path = os.path.join(
+        definition_path = self._get_json_definition_path(backup_date)
+        with open(definition_path, "w") as json_definition:
+            json.dump(definition, json_definition, indent=4)
+
+    def _clean_definition(self, definition={}):
+        backup_date = arrow.get(definition.get("date", self.pending_info["date"])).to(
+            "local"
+        )
+        os.remove(self._get_json_definition_path(backup_date))
+
+    def _get_json_definition_path(self, backup_date):
+        return os.path.join(
             self.backup_dir,
             "{}.{}".format(self._main_backup_name_format(backup_date), "json"),
         )
-        with open(definition_path, "w") as json_definition:
-            json.dump(definition, json_definition, indent=4)
 
     def _dump_pending_info(self):
         """
@@ -332,9 +366,7 @@ class DomBackup(_BaseDomBackup):
             not self._ext_snapshot_helper and self.pending_info.get("disks", None)
         )
         if is_ext_snap_helper_needed:
-            self._ext_snapshot_helper = DomExtSnapshot(
-                self.dom, self.disks, self._callbacks_registrer, self.conn, self.timeout
-            )
+            self._ext_snapshot_helper = self._get_ext_snapshot_helper()
             self._ext_snapshot_helper.metadatas = {
                 "disks": {
                     disk: {"src": val["src"], "snapshot": val["snapshot"]}
@@ -349,33 +381,24 @@ class DomBackup(_BaseDomBackup):
         if "name" in self.pending_info:
             packager = self._get_write_packager(self.pending_info["name"])
             try:
-                self._clean_packager(packager)
+                targets = []
+                for d in self.pending_info["disks"].values():
+                    if "target" in d:
+                        targets.append(d["target"])
+
+                self._clean_packager(packager, targets)
             except FileNotFoundError:
                 logger.info(
                     "%s: Packager not found, nothing to clean.", self.dom.name()
                 )
-        try:
-            self._clean_pending_info()
-        except FileNotFoundError:
-            # Pending info had no time to be filled, so had not be dumped.
-            pass
 
-    def _clean_packager(self, packager):
-        """
-        If the package is shareable, will remove each disk backup then will
-        only remove the packager if empty.
-        """
-        if packager.is_shareable:
-            targets = (d["target"] for d in self.pending_info["disks"].values())
-            with packager:
-                for target in targets:
-                    packager.remove(target)
-                if packager.list():
-                    # Other non related backups still exists, do not delete
-                    # the package.
-                    return
-
-        packager.remove_package()
+        if "date" in self.pending_info:
+            for cleaning in (self._clean_definition, self._clean_pending_info):
+                try:
+                    cleaning()
+                except FileNotFoundError:
+                    # Info had no time to be filled, so had not be dumped.
+                    pass
 
     def compatible_with(self, dombackup):
         """
