@@ -6,7 +6,7 @@ import os
 
 from virt_backup.backups import DomBackup, build_dom_complete_backup_from_def
 from virt_backup.domains import search_domains_regex
-from virt_backup.exceptions import BackupsFailureInGroupError
+from virt_backup.exceptions import BackupsFailureInGroupError, CancelledError
 from .pattern import matching_libvirt_domains_from_config
 
 
@@ -27,6 +27,9 @@ def groups_from_dict(groups_dict, conn, callbacks_registrer):
         hosts = properties.pop("hosts")
         include, exclude = [], []
         for host in hosts:
+            # TODO: matching should not filter some options. A function should be done
+            # here like the sanitize_properties to raise an error per host if the
+            # configuration is invalid.
             matches = matching_libvirt_domains_from_config(host, conn)
             if not matches.get("domains", None):
                 continue
@@ -48,7 +51,12 @@ def groups_from_dict(groups_dict, conn, callbacks_registrer):
             for domain_name in i["domains"]:
                 if domain_name not in exclude:
                     domain = conn.lookupByName(domain_name)
-                    backup_group.add_domain(domain, matches.get("disks", ()))
+                    sanitize_domain_properties(i["properties"])
+                    backup_group.add_domain(
+                        domain,
+                        i["properties"].get("disks", ()),
+                        quiesce=i["properties"].get("quiesce"),
+                    )
 
         return backup_group
 
@@ -68,6 +76,12 @@ def groups_from_dict(groups_dict, conn, callbacks_registrer):
 
         return properties
 
+    def sanitize_domain_properties(properties):
+        if properties.get("disks"):
+            properties["disks"] = sorted(properties["disks"])
+
+        return properties
+
     for group_name, group_properties in groups_dict.items():
         yield build(group_name, group_properties.copy())
 
@@ -107,7 +121,7 @@ class BackupGroup:
                     dom, disks = (bak_item, ())
                 self.add_domain(dom, disks)
 
-    def add_domain(self, dom, disks=()):
+    def add_domain(self, dom, disks=(), quiesce=None):
         """
         Add a domain and disks to backup in this group
 
@@ -124,9 +138,11 @@ class BackupGroup:
             existing_bak.add_disks(*disks)
         except StopIteration:
             # spawn a new DomBackup instance otherwise
-            self.backups.append(
-                DomBackup(dom=dom, dev_disks=disks, **self.default_bak_param)
-            )
+            kwargs = self.default_bak_param.copy()
+            if quiesce is not None:
+                kwargs["quiesce"] = quiesce
+
+            self.backups.append(DomBackup(dom=dom, dev_disks=disks, **kwargs))
 
     def add_dombackup(self, dombackup):
         """
@@ -214,32 +230,45 @@ class BackupGroup:
 
         completed_doms = []
         futures = {}
-        with concurrent.futures.ThreadPoolExecutor(nb_threads) as executor:
-            for backups_for_domain in backups_by_domain.values():
-                backup = backups_for_domain.pop()
-                future = self._submit_backup_future(executor, backup, completed_doms)
-                futures[future] = backup.dom
-
-            while len(futures) < len(self.backups):
-                next(concurrent.futures.as_completed(futures))
-                dom = completed_doms.pop()
-                if backups_by_domain.get(dom):
-                    backup = backups_by_domain[dom].pop()
+        try:
+            with concurrent.futures.ThreadPoolExecutor(nb_threads) as executor:
+                for backups_for_domain in backups_by_domain.values():
+                    backup = backups_for_domain.pop()
                     future = self._submit_backup_future(
                         executor, backup, completed_doms
                     )
-                    futures[future] = backup.dom
+                    futures[future] = backup
 
-        for f in concurrent.futures.as_completed(futures):
-            dom_name = futures[f].name()
-            try:
-                completed_backups[dom_name] = f.result()
-            except KeyboardInterrupt:
-                raise
-            except Exception as e:
-                error_backups[dom_name] = e
-                logger.error("Error with domain %s: %s", dom_name, e)
-                logger.exception(e)
+                while len(futures) < len(self.backups):
+                    next(concurrent.futures.as_completed(futures))
+                    dom = completed_doms.pop().dom
+                    if backups_by_domain.get(dom):
+                        backup = backups_by_domain[dom].pop()
+                        future = self._submit_backup_future(
+                            executor, backup, completed_doms
+                        )
+                        futures[future] = backup
+
+            for f in concurrent.futures.as_completed(futures):
+                dom_name = futures[f].dom.name()
+                try:
+                    completed_backups[dom_name] = f.result()
+                except KeyboardInterrupt:
+                    raise
+                except Exception as e:
+                    error_backups[dom_name] = e
+                    logger.error("Error with domain %s: %s", dom_name, e)
+                    logger.exception(e)
+        except:
+            for f in futures:
+                f.cancel()
+            for f in futures:
+                if f.running():
+                    logger.info("Cancel backup for domain %s", futures[f].dom.name())
+                    futures[f].cancel()
+
+            concurrent.futures.wait(futures)
+            raise
 
         if error_backups:
             raise BackupsFailureInGroupError(completed_backups, error_backups)
